@@ -33,7 +33,6 @@ import javax.sql.StatementEventListener;
  * PooledConnection and proxies events, allowing behavior to be
  * modified to simulate behavior of different implementations.
  * 
- * @version $Id: PooledConnectionProxy.java 1649424 2015-01-04 21:15:33Z tn $
  */
 public class PooledConnectionProxy implements PooledConnection,
     ConnectionEventListener {
@@ -52,7 +51,7 @@ public class PooledConnectionProxy implements PooledConnection,
      */
     private boolean notifyOnClose = false;
     
-    public PooledConnectionProxy(PooledConnection pooledConnection) {
+    public PooledConnectionProxy(final PooledConnection pooledConnection) {
         this.delegate = pooledConnection;
         pooledConnection.addConnectionEventListener(this);
     }
@@ -77,13 +76,13 @@ public class PooledConnectionProxy implements PooledConnection,
      * Remove event listeners.
      */
     @Override
-    public void removeConnectionEventListener(ConnectionEventListener listener) {
+    public void removeConnectionEventListener(final ConnectionEventListener listener) {
         eventListeners.remove(listener);
     }
 
     /* JDBC_4_ANT_KEY_BEGIN */
     @Override
-    public void removeStatementEventListener(StatementEventListener listener) {
+    public void removeStatementEventListener(final StatementEventListener listener) {
         eventListeners.remove(listener);
     }
     /* JDBC_4_ANT_KEY_END */
@@ -92,7 +91,7 @@ public class PooledConnectionProxy implements PooledConnection,
         return notifyOnClose;
     }
 
-    public void setNotifyOnClose(boolean notifyOnClose) {
+    public void setNotifyOnClose(final boolean notifyOnClose) {
         this.notifyOnClose = notifyOnClose;
     }
     
@@ -100,9 +99,9 @@ public class PooledConnectionProxy implements PooledConnection,
      * sends a connectionClosed event to listeners.
      */
     void notifyListeners() {
-        ConnectionEvent event = new ConnectionEvent(this);
-        Object[] listeners = eventListeners.toArray();
-        for (Object listener : listeners) {
+        final ConnectionEvent event = new ConnectionEvent(this);
+        final Object[] listeners = eventListeners.toArray();
+        for (final Object listener : listeners) {
             ((ConnectionEventListener) listener).connectionClosed(event);
         }
     }
@@ -111,7 +110,7 @@ public class PooledConnectionProxy implements PooledConnection,
      * Add event listeners.
      */
     @Override
-    public void addConnectionEventListener(ConnectionEventListener listener) {
+    public void addConnectionEventListener(final ConnectionEventListener listener) {
         if (!eventListeners.contains(listener)) {
             eventListeners.add(listener);
         }
@@ -119,7 +118,7 @@ public class PooledConnectionProxy implements PooledConnection,
 
     /* JDBC_4_ANT_KEY_BEGIN */
     @Override
-    public void addStatementEventListener(StatementEventListener listener) {
+    public void addStatementEventListener(final StatementEventListener listener) {
         if (!eventListeners.contains(listener)) {
             eventListeners.add(listener);
         }
@@ -130,7 +129,7 @@ public class PooledConnectionProxy implements PooledConnection,
      * Pass closed events on to listeners
      */
     @Override
-    public void connectionClosed(ConnectionEvent event) {
+    public void connectionClosed(final ConnectionEvent event) {
         notifyListeners();    
     }
 
@@ -138,9 +137,9 @@ public class PooledConnectionProxy implements PooledConnection,
      * Pass error events on to listeners
      */ 
     @Override
-    public void connectionErrorOccurred(ConnectionEvent event) {
-        Object[] listeners = eventListeners.toArray();
-        for (Object listener : listeners) {
+    public void connectionErrorOccurred(final ConnectionEvent event) {
+        final Object[] listeners = eventListeners.toArray();
+        for (final Object listener : listeners) {
             ((ConnectionEventListener) listener).connectionErrorOccurred(event);
         } 
     }
@@ -149,7 +148,7 @@ public class PooledConnectionProxy implements PooledConnection,
      * Generate a connection error event
      */
     public void throwConnectionError() {
-        ConnectionEvent event = new ConnectionEvent(this);
+        final ConnectionEvent event = new ConnectionEvent(this);
         connectionErrorOccurred(event);
     }
     
