@@ -47,7 +47,6 @@ import java.util.Properties;
  * TestSuite for ManagedDataSource without a transaction in progress.
  *
  * @author Dain Sundstrom
- * @version $Id: TestManagedDataSource.java 1691861 2015-07-19 23:15:15Z psteitz $
  */
 public class TestManagedDataSource extends TestConnectionPool {
 
@@ -66,16 +65,16 @@ public class TestManagedDataSource extends TestConnectionPool {
         transactionManager = new TransactionManagerImpl();
 
         // create a driver connection factory
-        Properties properties = new Properties();
+        final Properties properties = new Properties();
         properties.setProperty("user", "username");
         properties.setProperty("password", "password");
-        ConnectionFactory connectionFactory = new DriverConnectionFactory(new TesterDriver(), "jdbc:apache:commons:testdriver", properties);
+        final ConnectionFactory connectionFactory = new DriverConnectionFactory(new TesterDriver(), "jdbc:apache:commons:testdriver", properties);
 
         // wrap it with a LocalXAConnectionFactory
-        XAConnectionFactory xaConnectionFactory = new LocalXAConnectionFactory(transactionManager, connectionFactory);
+        final XAConnectionFactory xaConnectionFactory = new LocalXAConnectionFactory(transactionManager, connectionFactory);
 
         // create the pool object factory
-        PoolableConnectionFactory factory =
+        final PoolableConnectionFactory factory =
             new PoolableConnectionFactory(xaConnectionFactory, null);
         factory.setValidationQuery("SELECT DUMMY FROM DUAL");
         factory.setDefaultReadOnly(Boolean.TRUE);
@@ -92,6 +91,7 @@ public class TestManagedDataSource extends TestConnectionPool {
         ds.setAccessToUnderlyingConnectionAllowed(true);
     }
 
+    @Override
     @After
     public void tearDown() throws Exception {
         pool.close();
@@ -123,8 +123,8 @@ public class TestManagedDataSource extends TestConnectionPool {
      */
     @Test
     public void testSharedConnection() throws Exception {
-        DelegatingConnection<?> connectionA = (DelegatingConnection<?>) newConnection();
-        DelegatingConnection<?> connectionB = (DelegatingConnection<?>) newConnection();
+        final DelegatingConnection<?> connectionA = (DelegatingConnection<?>) newConnection();
+        final DelegatingConnection<?> connectionB = (DelegatingConnection<?>) newConnection();
 
         assertFalse(connectionA.equals(connectionB));
         assertFalse(connectionB.equals(connectionA));
@@ -138,7 +138,7 @@ public class TestManagedDataSource extends TestConnectionPool {
     @Test
     public void testConnectionReturnOnCommit() throws Exception {
         transactionManager.begin();
-        DelegatingConnection<?> connectionA = (DelegatingConnection<?>) newConnection();
+        final DelegatingConnection<?> connectionA = (DelegatingConnection<?>) newConnection();
         connectionA.close();
         transactionManager.commit();
         assertEquals(1, pool.getBorrowedCount());
@@ -149,7 +149,7 @@ public class TestManagedDataSource extends TestConnectionPool {
     @Test
     public void testManagedConnectionEqualsSameDelegateNoUnderlyingAccess() throws Exception {
         // Get a maximal set of connections from the pool
-        Connection[] c = new Connection[getMaxTotal()];
+        final Connection[] c = new Connection[getMaxTotal()];
         for (int i = 0; i < c.length; i++) {
             c[i] = newConnection();
         }
@@ -160,12 +160,12 @@ public class TestManagedDataSource extends TestConnectionPool {
         ds.setAccessToUnderlyingConnectionAllowed(false);
         // Grab a new connection - should get c[0]'s closed connection
         // so should be delegate-equivalent
-        Connection con = newConnection();
+        final Connection con = newConnection();
         Assert.assertNotEquals(c[0], con);
         Assert.assertEquals(
                 ((DelegatingConnection<?>) c[0]).getInnermostDelegateInternal(),
                 ((DelegatingConnection<?>) con).getInnermostDelegateInternal());
-        for (Connection element : c) {
+        for (final Connection element : c) {
             element.close();
         }
         ds.setAccessToUnderlyingConnectionAllowed(true);
@@ -174,7 +174,7 @@ public class TestManagedDataSource extends TestConnectionPool {
     @Test
     public void testManagedConnectionEqualsSameDelegate() throws Exception {
         // Get a maximal set of connections from the pool
-        Connection[] c = new Connection[getMaxTotal()];
+        final Connection[] c = new Connection[getMaxTotal()];
         for (int i = 0; i < c.length; i++) {
             c[i] = newConnection();
         }
@@ -183,12 +183,12 @@ public class TestManagedDataSource extends TestConnectionPool {
 
         // Grab a new connection - should get c[0]'s closed connection
         // so should be delegate-equivalent
-        Connection con = newConnection();
+        final Connection con = newConnection();
         Assert.assertNotEquals(c[0], con);
         Assert.assertEquals(
                 ((DelegatingConnection<?>) c[0]).getInnermostDelegateInternal(),
                 ((DelegatingConnection<?>) con).getInnermostDelegateInternal());
-        for (Connection element : c) {
+        for (final Connection element : c) {
             element.close();
         }
     }
@@ -198,8 +198,8 @@ public class TestManagedDataSource extends TestConnectionPool {
     */
     @Test
     public void testManagedConnectionEqualsReflexive() throws Exception {
-        Connection con = ds.getConnection();
-        Connection con2 = con;
+        final Connection con = ds.getConnection();
+        final Connection con2 = con;
         assertTrue(con2.equals(con));
         assertTrue(con.equals(con2));
         con.close();
@@ -207,8 +207,8 @@ public class TestManagedDataSource extends TestConnectionPool {
 
     @Test
     public void testManagedConnectionEqualsFail() throws Exception {
-        Connection con1 = ds.getConnection();
-        Connection con2 = ds.getConnection();
+        final Connection con1 = ds.getConnection();
+        final Connection con2 = ds.getConnection();
         assertFalse(con1.equals(con2));
         con1.close();
         con2.close();
@@ -216,16 +216,16 @@ public class TestManagedDataSource extends TestConnectionPool {
 
     @Test
     public void testManagedConnectionEqualsNull() throws Exception {
-        Connection con1 = ds.getConnection();
-        Connection con2 = null;
+        final Connection con1 = ds.getConnection();
+        final Connection con2 = null;
         assertFalse(con1.equals(con2));
         con1.close();
     }
 
     @Test
     public void testManagedConnectionEqualsType() throws Exception {
-        Connection con1 = ds.getConnection();
-        Integer con2 = Integer.valueOf(0);
+        final Connection con1 = ds.getConnection();
+        final Integer con2 = Integer.valueOf(0);
         assertFalse(con1.equals(con2));
         con1.close();
     }
@@ -233,29 +233,29 @@ public class TestManagedDataSource extends TestConnectionPool {
     @Test
     public void testManagedConnectionEqualInnermost() throws Exception {
         ds.setAccessToUnderlyingConnectionAllowed(true);
-        DelegatingConnection<?> con = (DelegatingConnection<?>) ds.getConnection();
-        Connection inner = con.getInnermostDelegate();
+        final DelegatingConnection<?> con = (DelegatingConnection<?>) ds.getConnection();
+        final Connection inner = con.getInnermostDelegate();
         ds.setAccessToUnderlyingConnectionAllowed(false);
-        DelegatingConnection<Connection> con2 = new DelegatingConnection<>(inner);
+        final DelegatingConnection<Connection> con2 = new DelegatingConnection<>(inner);
         assertFalse(con2.equals(con));
         assertTrue(con.innermostDelegateEquals(con2.getInnermostDelegate()));
         assertTrue(con2.innermostDelegateEquals(inner));
         assertFalse(con.equals(con2));
     }
-    
+
     @Test
     public void testNestedConnections() throws Exception {
         transactionManager.begin();
-        
+
         Connection c1 = null;
         Connection c2 = null;
-        
+
         c1 = newConnection();
         c2 = newConnection();
-        
+
         transactionManager.commit();
-        
+
         c1.close();
         c2.close();
-    }   
+    }
 }
